package com.qiaoba.api.system.service;

import com.qiaoba.api.system.entity.SysUser;
import com.qiaoba.api.system.entity.dto.ResetPwdDto;
import com.qiaoba.api.system.entity.dto.ResetUserStatusDto;
import com.qiaoba.api.system.entity.dto.SysUserDto;
import com.qiaoba.api.system.entity.param.SysUserParam;
import com.qiaoba.api.system.entity.vo.SysUserVo;

import java.util.List;
import java.util.Set;

/**
 * 用户对外暴露接口
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023-04-23 20:33:43
 */
public interface SysUserApiService {

    /**
     * 新增或更新用户
     *
     * @param dto      dto
     * @param isUpdate 是->更新
     * @return > 0 = success
     */
    int saveOrUpdate(SysUserDto dto, Boolean isUpdate);

    /**
     * 查询用户
     *
     * @param userId      userId
     * @param hasPassword 是否需要密码
     * @return SysUser
     */
    SysUser selectById(String userId, Boolean hasPassword);

    /**
     * 重置密码
     *
     * @param dto dto
     * @return 结果
     */
    int resetPwd(ResetPwdDto dto);

    /**
     * 更改用户状态
     *
     * @param dto dto
     * @return 结果
     */
    int updateUserStatus(ResetUserStatusDto dto);

    /**
     * 批量删除
     *
     * @param userIds      userIds
     * @param isSoftDelete 是否软删除
     * @return 结果
     */
    int deleteByIds(List<String> userIds, Boolean isSoftDelete);

    /**
     * 用户绑定角色
     *
     * @param userId   userId
     * @param roleIds  roleIds
     * @param isUpdate 是否是更新操作
     */
    void handleUserRole(String userId, Set<String> roleIds, boolean isUpdate);

    /**
     * 查询用户列表
     *
     * @param param 查询条件
     * @return list
     */
    List<SysUserVo> selectVoList(SysUserParam param);

}
