package com.qiaoba.common.database.config;

import com.qiaoba.common.database.constants.DynamicDatasourceConstant;
import org.springframework.jdbc.datasource.lookup.AbstractRoutingDataSource;

import java.util.Map;

/**
 * 动态数据源上下文对象
 *
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 16:43
 */
public class DynamicDataSourceContext extends AbstractRoutingDataSource {


    private static final ThreadLocal<String> CONTEXT_HOLDER = new ThreadLocal<>();


    /**
     * 设置默认数据源、全部数据源，及刷新
     */
    public void freshDataSource(Map<Object, Object> targetDataSources) {
        //默认数据源
        super.setDefaultTargetDataSource(targetDataSources.get(DynamicDatasourceConstant.DEFAULT_MASTER_DATASOURCE_KEY));
        //设置全部数据源
        super.setTargetDataSources(targetDataSources);
        //刷新(即把targetDataSources刷到resolvedDataSources中去，resolvedDataSources才是我们真正存放数据源的map)
        super.afterPropertiesSet();
    }

    @Override
    protected Object determineCurrentLookupKey() {
        //获取当前指定的数据源
        return getDataSource();
    }


    @Override
    public void afterPropertiesSet() {
    }

    /**
     * 获取上下文中的数据源
     */
    public String getDataSource() {
        return CONTEXT_HOLDER.get();
    }

    /**
     * 设置上下文中的数据源
     */
    public void setDataSource(String dataSource) {
        CONTEXT_HOLDER.set(dataSource);
    }

    /**
     * 清除上下文中的数据源
     */
    public void clearDataSource() {
        CONTEXT_HOLDER.remove();
    }
}
