package com.qiaoba.common.database.filters;

import com.qiaoba.common.database.config.DynamicDataSourceContext;
import com.qiaoba.common.database.constants.DynamicDatasourceConstant;
import com.qiaoba.common.database.utils.TenantUtil;
import com.qiaoba.common.web.utils.ResponseUtil;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * 动态切换不同租户的数据源
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023-04-25 22:48:43
 */
@Component
@Order(-10000)
public class DynamicDataSourceFilter implements Filter {

    @Resource
    private DynamicDataSourceContext dynamicDataSourceContext;

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        //设置当前租户对应的数据库
        dynamicDataSourceContext.setDataSource(DynamicDatasourceConstant.DEFAULT_MASTER_DATASOURCE_KEY);
        TenantUtil.setTenantId("1");
        filterChain.doFilter(servletRequest, servletResponse);
        dynamicDataSourceContext.clearDataSource();
        TenantUtil.clearTenantId();
    }

    private boolean checkTenantInfo(String tenantCode, ServletResponse servletResponse) throws IOException {
        // 检查租户的信息,是否存在,是否过期,是否禁用
        ResponseUtil.response((HttpServletResponse) servletResponse, "租户: " + tenantCode + "已到期");
        return false;
    }

}
