package com.qiaoba.common.web.advice;


import com.qiaoba.common.base.exceptions.ServiceException;
import com.qiaoba.common.base.result.AjaxResult;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * 全局异常处理
 *
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 16:43
 */
@ControllerAdvice
public class ExceptionAdvice {

    /**
     * 非自定义异常
     *
     * @param e Exception
     * @return AjaxResult
     */
    @ExceptionHandler(value = Exception.class)
    @ResponseBody
    public AjaxResult error(Exception e) {
        e.printStackTrace();
        return AjaxResult.error(e.getMessage());
    }

    /**
     * 自定义异常, 控制台不打印
     *
     * @param e ServiceException
     * @return AjaxResult
     */
    @ExceptionHandler(ServiceException.class)
    @ResponseBody
    public AjaxResult handlerApiException(ServiceException e) {
        return AjaxResult.error(e.getMessage());
    }

}
