package com.qiaoba.module.system.controller;

import com.qiaoba.api.system.entity.SysDept;
import com.qiaoba.api.system.entity.param.SysDeptParam;
import com.qiaoba.common.base.result.AjaxResult;
import com.qiaoba.module.system.service.SysDeptService;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 部门管理 Web层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/6 15:06
 */
@RestController
@RequestMapping("/system/dept")
@RequiredArgsConstructor
public class SysDeptController {

    private final SysDeptService sysDeptService;

    //@PreAuthorize("hasAuthority('system:dept:list')")
    @GetMapping("/list")
    public AjaxResult list(SysDeptParam param) {
        return AjaxResult.success(sysDeptService.selectList(param));
    }

    //@PreAuthorize("hasAuthority('system:dept:list')")
    @GetMapping("/list/exclude/{deptId}")
    public AjaxResult excludeChild(@PathVariable(value = "deptId", required = false) String deptId) {
        return AjaxResult.success(sysDeptService.excludeChild(deptId));
    }

    //@PreAuthorize("hasAuthority('system:dept:query')")
    @GetMapping(value = "/{deptId}")
    public AjaxResult getInfo(@PathVariable Long deptId) {
        return AjaxResult.success(sysDeptService.selectById(deptId));
    }

    @GetMapping("/deptTree")
    public AjaxResult deptTree(SysDeptParam param) {
        List<SysDept> list = sysDeptService.selectList(param);
        return AjaxResult.success(sysDeptService.buildDeptTree(list));
    }

    //@PreAuthorize("hasAuthority('system:dept:add')")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysDept dept) {
        return AjaxResult.toAjax(sysDeptService.insert(dept));
    }

    //@PreAuthorize("hasAuthority('system:dept:edit')")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysDept dept) {
        return AjaxResult.toAjax(sysDeptService.updateById(dept));
    }

    //@PreAuthorize("hasAuthority('system:dept:remove')")
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id) {
        return AjaxResult.toAjax(sysDeptService.deleteById(id));
    }
}
