package com.qiaoba.module.system.controller;

import com.qiaoba.api.system.entity.SysMenu;
import com.qiaoba.api.system.entity.param.SysMenuParam;
import com.qiaoba.api.system.entity.vo.SysMenuVo;
import com.qiaoba.common.base.result.AjaxResult;
import com.qiaoba.common.security.utils.SecurityUtil;
import com.qiaoba.module.system.service.SysMenuService;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 菜单管理 Web层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/5 10:06
 */
@RestController
@RequestMapping("/system/menu")
@RequiredArgsConstructor
public class SysMenuController {

    private final SysMenuService sysMenuService;

    @GetMapping("/list")
    public AjaxResult list(SysMenuParam param) {
        List<SysMenuVo> menus = sysMenuService.selectVoList(param);
        return AjaxResult.success(menus);
    }

    //@PreAuthorize("hasAuthority('system:menu:query')")
    @GetMapping(value = "/{menuId}")
    public AjaxResult getInfo(@PathVariable String menuId) {
        return AjaxResult.success(sysMenuService.selectById(menuId));
    }

    //@PreAuthorize("hasAuthority('system:menu:add')")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysMenu menu) {
        return AjaxResult.toAjax(sysMenuService.insert(menu));
    }

    //@PreAuthorize("hasAuthority('system:menu:edit')")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysMenu menu) {
        return AjaxResult.toAjax(sysMenuService.updateById(menu));
    }

    //@PreAuthorize("hasAuthority('system:menu:remove')")
    @DeleteMapping("/{menuId}")
    public AjaxResult remove(@PathVariable("menuId") String menuId) {
        return AjaxResult.toAjax(sysMenuService.deleteById(menuId));
    }

    @GetMapping("/tree_select")
    public AjaxResult treeSelect(SysMenuParam param) {
        List<SysMenuVo> menus = sysMenuService.selectVoList(param);
        return AjaxResult.success(sysMenuService.buildMenuTree(menus));
    }

    @GetMapping(value = "/role_menu_tree_select/{roleId}")
    public AjaxResult roleMenuTreeSelect(@PathVariable("roleId") String roleId) {
        AjaxResult ajax = AjaxResult.success();
        ajax.put("checkedKeys", sysMenuService.selectMenuIdsByRoleId(roleId));
        ajax.put("menus", sysMenuService.buildMenuTree(sysMenuService.selectVoList(new SysMenuParam())));
        return ajax;
    }
}
