package com.qiaoba.module.system.controller;

import com.qiaoba.api.system.entity.SysPost;
import com.qiaoba.api.system.entity.param.SysPostParam;
import com.qiaoba.common.base.result.AjaxResult;
import com.qiaoba.common.database.entity.PageQuery;
import com.qiaoba.common.database.entity.TableDataInfo;
import com.qiaoba.common.poi.utils.ExcelUtil;
import com.qiaoba.module.system.service.SysPostService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 岗位管理 web层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2022-09-22 04:20:28
 */
@RestController
@RequestMapping("/system/post")
@RequiredArgsConstructor
public class SysPostController {

    private final SysPostService sysPostService;

    /**
     * 获取岗位列表
     */
    @GetMapping("/list")
    //@PreAuthorize("hasAuthority('system:post:list')")
    public TableDataInfo<SysPost> list(SysPostParam param, PageQuery pageQuery) {
        return sysPostService.selectPageList(param, pageQuery);
    }

    @PostMapping("/export")
    //@PreAuthorize("hasAuthority('system:post:export')")
    public void export(HttpServletResponse response, SysPostParam param) {
        List<SysPost> list = sysPostService.selectList(param);
        ExcelUtil.exportExcel(list, SysPost.class, "岗位数据", response);
    }

    /**
     * 根据岗位编号获取详细信息
     */
    @GetMapping(value = "/{postId}")
    //@PreAuthorize("hasAuthority('system:post:query')")
    public AjaxResult getInfo(@PathVariable("postId") String postId) {
        return AjaxResult.success(sysPostService.selectById(postId));
    }

    /**
     * 新增岗位
     */
    @PostMapping
    //@PreAuthorize("hasAuthority('system:post:add')")
    public AjaxResult add(@RequestBody SysPost post) {
        return AjaxResult.toAjax(sysPostService.insert(post));
    }

    /**
     * 修改岗位
     */
    @PutMapping
    //@PreAuthorize("hasAuthority('system:post:edit')")
    public AjaxResult edit(@RequestBody SysPost post) {
        return AjaxResult.toAjax(sysPostService.updateById(post));
    }

    /**
     * 删除岗位
     */
    @DeleteMapping("/{ids}")
    //@PreAuthorize("hasAuthority('system:post:remove')")
    public AjaxResult remove(@PathVariable List<String> ids) {
        return AjaxResult.toAjax(sysPostService.deleteByIds(ids));
    }

    /**
     * 获取岗位选择框列表
     */
/*    @GetMapping("/optionSelect")
    public AjaxResult optionSelect() {
        List<SysPost> posts = postService.selectPostAll();
        return AjaxResult.success(posts);
    }*/
}
