package com.qiaoba.module.system.controller;

import com.qiaoba.api.system.entity.SysRole;
import com.qiaoba.api.system.entity.dto.DataScopeDto;
import com.qiaoba.api.system.entity.dto.SysRoleDto;
import com.qiaoba.api.system.entity.param.SysRoleParam;
import com.qiaoba.api.system.entity.param.SysUserParam;
import com.qiaoba.common.base.result.AjaxResult;
import com.qiaoba.common.database.entity.PageQuery;
import com.qiaoba.common.database.entity.TableDataInfo;
import com.qiaoba.module.system.service.SysDeptService;
import com.qiaoba.module.system.service.SysRoleService;
import com.qiaoba.module.system.service.SysUserRoleService;
import com.qiaoba.module.system.service.SysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 角色管理 web层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2022-09-22 04:20:28
 */
@RestController
@RequestMapping("/system/role")
@RequiredArgsConstructor
public class SysRoleController {

    private final SysRoleService sysRoleService;
    private final SysDeptService sysDeptService;
    private final SysUserService sysUserService;
    private final SysUserRoleService sysUserRoleService;

    //@PreAuthorize("hasAuthority('system:role:list')")
    @GetMapping("/list")
    public TableDataInfo<SysRole> list(SysRoleParam param, PageQuery pageQuery) {
        return sysRoleService.selectPageList(param, pageQuery);
    }

    //@PreAuthorize("hasAuthority('system:role:query')")
    @GetMapping(value = "/{roleId}")
    public AjaxResult getInfo(@PathVariable String roleId) {
        return AjaxResult.success(sysRoleService.selectById(roleId));
    }

    //@PreAuthorize("hasAuthority('system:role:add')")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysRoleDto roleDto) {
        return AjaxResult.toAjax(sysRoleService.insert(roleDto));

    }

    //@PreAuthorize("hasAuthority('system:role:edit')")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysRoleDto roleDto) {
        return AjaxResult.toAjax(sysRoleService.updateById(roleDto));

    }

    //@PreAuthorize("hasAuthority('system:role:edit')")
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody SysRoleDto dto) {
        return AjaxResult.toAjax(sysRoleService.updateById(dto));
    }

    //@PreAuthorize("hasAuthority('system:role:remove')")
    @DeleteMapping("/{roleIds}")
    public AjaxResult remove(@PathVariable List<String> roleIds) {
        return AjaxResult.toAjax(sysRoleService.deleteByIds(roleIds));
    }

    //@PreAuthorize("hasAuthority('system:role:query')")
    @GetMapping(value = "/deptTree/{roleId}")
    public AjaxResult deptTree(@PathVariable("roleId") String roleId) {
        AjaxResult ajax = AjaxResult.success();
        ajax.put("checkedKeys", sysDeptService.selectDeptIdsByRoleId(roleId));
        ajax.put("depts", sysDeptService.selectDeptTree());
        return ajax;
    }

    //@PreAuthorize("hasAuthority('system:role:edit')")
    @PutMapping("/dataScope")
    public AjaxResult dataScope(@RequestBody DataScopeDto dto) {
        return AjaxResult.toAjax(sysRoleService.authDataScope(dto));
    }

    //@PreAuthorize("hasAuthority('system:role:list')")
    @GetMapping("/authUser/allocatedList")
    public TableDataInfo allocatedList(SysUserParam param, PageQuery pageQuery) {
        return sysUserService.selectAllocatedList(param, pageQuery);
    }

    //@PreAuthorize("hasAuthority('system:role:edit')")
    @PutMapping("/authUser/cancel")
    public AjaxResult cancelAuthUser(@RequestParam("roleId") String roleId, @RequestParam("userIds") List<String> userIds) {
        sysUserRoleService.deleteByRoleIdAndUserIds(roleId, userIds);
        return AjaxResult.success();
    }

    /**
     * 查询未分配用户角色列表
     */
    //@PreAuthorize("hasAuthority('system:role:list')")
    @GetMapping("/authUser/unallocatedList")
    public TableDataInfo unallocatedList(SysUserParam param, PageQuery pageQuery) {
        return sysUserService.selectUnAllocatedList(param, pageQuery);
    }

    /**
     * 批量选择用户授权
     */
    //@PreAuthorize("hasAuthority('system:role:edit')")
    @PutMapping("/authUser/insert")
    public AjaxResult insertAuthUsers(@RequestParam("roleId") String roleId, @RequestParam("userIds") List<String> userIds) {
        sysUserRoleService.insertAuthUsers(roleId, userIds);
        return AjaxResult.success();
    }

}
