package com.qiaoba.module.system.controller;

import cn.hutool.core.util.StrUtil;
import com.qiaoba.api.system.entity.SysRole;
import com.qiaoba.api.system.entity.SysUser;
import com.qiaoba.api.system.entity.dto.ResetPwdDto;
import com.qiaoba.api.system.entity.dto.ResetUserStatusDto;
import com.qiaoba.api.system.entity.dto.SysUserDto;
import com.qiaoba.api.system.entity.param.SysPostParam;
import com.qiaoba.api.system.entity.param.SysRoleParam;
import com.qiaoba.api.system.entity.param.SysUserParam;
import com.qiaoba.api.system.entity.vo.SysUserVo;
import com.qiaoba.common.base.enums.BaseEnum;
import com.qiaoba.common.base.result.AjaxResult;
import com.qiaoba.common.database.entity.PageQuery;
import com.qiaoba.common.database.entity.TableDataInfo;
import com.qiaoba.common.poi.utils.ExcelUtil;
import com.qiaoba.module.system.service.*;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 用户管理 web层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023-04-23 20:51:26
 */
@RestController
@RequestMapping("/system/user")
@Tag(name = "用户管理")
@RequiredArgsConstructor
public class SysUserController {

    private final SysUserService sysUserService;
    private final SysRoleService sysRoleService;
    private final SysPostService sysPostService;
    private final SysUserPostService sysUserPostService;
    private final SysUserRoleService sysUserRoleService;

    //@PreAuthorize("hasAuthority('system:user:add')")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysUserDto dto) {
        return AjaxResult.toAjax(sysUserService.saveOrUpdate(dto, false));
    }

    //@PreAuthorize("hasAuthority('system:user:edit')")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SysUserDto dto) {
        return AjaxResult.toAjax(sysUserService.saveOrUpdate(dto, true));
    }

    //@PreAuthorize("hasAuthority('system:user:resetPwd')")
    @PutMapping("/resetPwd")
    public AjaxResult resetPwd(@RequestBody ResetPwdDto dto) {
        return AjaxResult.toAjax(sysUserService.resetPwd(dto));
    }

    //@PreAuthorize("hasAuthority('system:user:edit')")
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody ResetUserStatusDto dto) {
        return AjaxResult.toAjax(sysUserService.updateUserStatus(dto));
    }

    //@PreAuthorize("hasAuthority('system:user:remove')")
    @DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable List<String> userIds) {
        return AjaxResult.toAjax(sysUserService.deleteByIds(userIds, true));
    }

    @GetMapping("/list")
    public TableDataInfo<SysUserVo> list(SysUserParam param, PageQuery pageQuery) {
        return sysUserService.selectVoPageList(param, pageQuery);
    }

    //@PreAuthorize("hasAuthority('system:user:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUserParam param) {
        List<SysUserVo> list = sysUserService.selectVoList(param);
        ExcelUtil.exportExcel(list, SysUserVo.class, "用户数据", response);
    }

    //@PreAuthorize("hasAuthority('system:user:query')")
    @GetMapping(value = {"/", "/{userId}"})
    public AjaxResult getInfo(@PathVariable(value = "userId", required = false) String userId) {
        AjaxResult ajax = AjaxResult.success();
        List<SysRole> roles = sysRoleService.selectList(new SysRoleParam());
        ajax.put("roles", roles);
        ajax.put("posts", sysPostService.selectList(new SysPostParam(BaseEnum.NORMAL.getCode())));
        if (StrUtil.isNotBlank(userId)) {
            SysUser sysUser = sysUserService.selectById(userId, false);
            ajax.put(AjaxResult.DATA_TAG, sysUser);
            ajax.put("postIds", sysUserPostService.selectPostIdsByUserId(userId));
            ajax.put("roleIds", sysUserRoleService.selectRoleIdsByUserId(userId));
        }
        return ajax;
    }

    //@PreAuthorize("hasAuthority('system:user:query')")
    @GetMapping("/authRole/{userId}")
    public AjaxResult authRole(@PathVariable("userId") String userId) {
        AjaxResult ajax = AjaxResult.success();
        SysUser user = sysUserService.selectById(userId, false);
        List<SysRole> roles = sysRoleService.selectList(new SysRoleParam());
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("hasRoleIds", sysUserRoleService.selectRoleIdsByUserId(userId));
        return ajax;
    }

    //@PreAuthorize("hasAuthority('system:user:edit')")
    @PutMapping("/authRole")
    public AjaxResult handleUserRole(String userId, String[] roleIds) {
        sysUserService.handleUserRole(userId, Arrays.stream(roleIds).collect(Collectors.toSet()), true);
        return AjaxResult.success();
    }
}
