package com.qiaoba.module.system.service.impl;

import cn.hutool.core.lang.tree.Tree;
import cn.hutool.core.lang.tree.TreeNodeConfig;
import cn.hutool.core.lang.tree.TreeUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qiaoba.api.system.entity.SysMenu;
import com.qiaoba.api.system.entity.param.SysMenuParam;
import com.qiaoba.api.system.entity.vo.SysMenuVo;
import com.qiaoba.common.base.constants.BaseConstant;
import com.qiaoba.common.base.exceptions.ServiceException;
import com.qiaoba.module.system.mapper.SysMenuMapper;
import com.qiaoba.module.system.service.SysMenuService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 菜单管理 服务层实现
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/5 11:30
 */
@Service
@RequiredArgsConstructor
public class SysMenuServiceImpl implements SysMenuService {

    private final SysMenuMapper sysMenuMapper;

    @Override
    public int insert(SysMenu sysMenu) {
        if (checkMenuNameNotUnique(sysMenu)) {
            throw new ServiceException("同级下菜单名称不允许重复!");
        }
        sysMenu.setCreateTime(new Date());
        return sysMenuMapper.insert(sysMenu);
    }

    @Override
    public int updateById(SysMenu sysMenu) {
        if (checkMenuNameNotUnique(sysMenu)) {
            throw new ServiceException("同级下菜单名称不允许重复!");
        }
        return sysMenuMapper.updateById(sysMenu);
    }

    @Override
    public List<SysMenuVo> selectVoList(SysMenuParam param) {
        return sysMenuMapper.selectVoList(param2Wrapper((param)));
    }

    @Override
    public SysMenu selectById(String menuId) {
        return sysMenuMapper.selectById(menuId);
    }

    @Override
    public int deleteById(String menuId) {
        return sysMenuMapper.deleteById(menuId);
    }

    private QueryWrapper<SysMenu> param2Wrapper(SysMenuParam param) {
        QueryWrapper<SysMenu> wrapper = new QueryWrapper<>();
        wrapper.lambda()
                .orderByAsc(SysMenu::getOrderNum)
                .eq(StrUtil.isNotBlank(param.getIsVisible()), SysMenu::getIsVisible, param.getIsVisible())
                .like(StrUtil.isNotBlank(param.getMenuName()), SysMenu::getMenuName, param.getMenuName());
        return wrapper;
    }

    @Override
    public List<Tree<String>> buildMenuTree(List<SysMenuVo> menus) {
        TreeNodeConfig config = TreeNodeConfig.DEFAULT_CONFIG.setNameKey(BaseConstant.TREE_KEY_NAME);
        return TreeUtil.build(menus, BaseConstant.DEFAULT_PARENT_ID_VALUE, config, (menu, tree) ->
                tree.setId(menu.getMenuId())
                        .setParentId(menu.getParentId())
                        .setName(menu.getMenuName())
                        .setWeight(menu.getOrderNum()));
    }

    @Override
    public List<String> selectMenuIdsByRoleId(String roleId) {
        return sysMenuMapper.selectMenuIdsByRoleId(roleId);
    }

    private boolean checkMenuNameNotUnique(SysMenu menu) {
        return sysMenuMapper.checkMenuNameUnique(menu) > 0;
    }
}
