package com.qiaoba.module.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.toolkit.Db;
import com.qiaoba.api.system.entity.SysUserRole;
import com.qiaoba.module.system.mapper.SysUserRoleMapper;
import com.qiaoba.module.system.service.SysUserRoleService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 用户角色关联 服务层实现
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/10 13:03
 */
@Service
@RequiredArgsConstructor
public class SysUserRoleServiceImpl implements SysUserRoleService {

    private final SysUserRoleMapper sysUserRoleMapper;

    @Override
    public void insertBatch(List<SysUserRole> list) {
        Db.saveBatch(list);
    }

    @Override
    public void deleteByUserId(String userId) {
        sysUserRoleMapper.delete(createWrapper(userId));
    }

    @Override
    public void deleteByRoleIdAndUserIds(String roleId, List<String> userIds) {
        sysUserRoleMapper.deleteByRoleIdAndUserIds(roleId, userIds);
    }

    @Override
    public List<String> selectRoleIdsByUserId(String userId) {
        return sysUserRoleMapper.selectRoleIdsByUserId(userId);
    }

    @Override
    public void insertAuthUsers(String roleId, List<String> userIds) {
        List<SysUserRole> list = new ArrayList<>();
        for (String userId : userIds) {
            list.add(new SysUserRole(userId, roleId));
        }
        Db.saveBatch(list);
    }

    private QueryWrapper<SysUserRole> createWrapper(String userId) {
        QueryWrapper<SysUserRole> wrapper = new QueryWrapper<>();
        wrapper.lambda()
                .eq(SysUserRole::getUserId, userId);
        return wrapper;
    }
}
